/**
 * 获得有效值，不在有效内的值会变成null
 * @param value 被检测的值
 * @returns 被处理成有效值的值
 */
export var getValidVal = function getValidVal(value) {
  switch (getValueType(value)) {
    case 'Array':
      {
        // 数组类型，且数组数目大于0，则有效值为value，否则为null
        if (value.length) {
          return value;
        }
        return null;
      }
    case 'Object':
      {
        // 对象类型，专属属性数目大于0时，有效值为value，否则为null
        if (Object.keys(value).length) {
          return value;
        }
        return null;
      }
    case 'String':
      {
        // 字符串类型，非空时，有效值为value，否则为null
        if (value) {
          return value;
        }
        return null;
      }
    case 'Number':
      {
        // 数值类型，0和其他正常数值时，有效值为value，否则为null
        if (value === 0 || value && value !== Infinity) {
          return value;
        }
        return null;
      }
    case 'Boolean':
      {
        // 布尔类型，有效值为value
        return value;
      }
    default:
      {
        // 其他类型，默认返回null
        return null;
      }
  }
};

/**
 * 获取对象类型
 * @param value 目标对象
 * @returns IObjectType
 */
export var getValueType = function getValueType(value) {
  var originalStr = Object.prototype.toString.call(value);
  return originalStr.slice(1, -1).split(' ')[1];
};